'''
pyChatGPTLoop

An unofficial Python wrapper for OpenAI's ChatGPT API
and add backtracking chat on the basis of pyChatGPT
'''


from .pyChatGPTLoop import ChatGPT

__all__ = ['ChatGPT']
